@@ -2,7 +2,7 @@
 #' 
 #' Get KOMs/QOMs/CRs of an athlete
 #' 
-#' @param id string or integer of athlete
+#' @param id string of athlete id
 #' @param stoken A \code{\link[httr]{config}} object created using the \code{\link{strava_oauth}} function
 #'
 #' @details Requires authentication stoken using the \code{\link{strava_oauth}} function and a user-created API on the strava website.   
@@ -22,10 +22,13 @@
 #' stoken <- httr::config(token = strava_oauth(app_name, app_client_id, 
 #' 	app_secret, cache = TRUE))
 #' 
-#' get_KOMs(2837007, stoken)
+#' get_KOMs('2837007', stoken)
 #' }
 get_KOMs <- function(id, stoken){
 
+	if(any(!is.character(id))) 
+		stop('id must be a character vector')
+	
 	url_ <- paste(url_athlete(id),"/koms", sep = "")
 	dataRaw <- get_basic(url_, stoken)
 	return(dataRaw)
